/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"
#include "HvSignalBiquad.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvMath.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_nBIGzMcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jIeXkevX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6AaoZo3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zd2aB6k7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0dDeyIVs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_blSeE2n0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jXKnrMvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Hfss78yL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oUOcS75y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LirEINOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0mYtLwHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wqpjjrbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BEl6I1QO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wq1HkfCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jw2VyW14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JMuIX05c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x7EKmf7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1i4k6pue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tTcZ9fyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_74PpA4qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6vMWDlon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pgqGWJ7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vmsUHGuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnXNb5oO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O6oUKQGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rWTnwVBA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u4p6tqha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sR4Ldj2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nkWKiObo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5JG4Eaoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oXORB5PU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KMNrn3Uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9oTgeodF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EMdcMm3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2IUrCFxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j5OmVygd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mZRkGj2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gZPIZGjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8SK7IoGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d9iYN5Fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iVcJ3haH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bRFhY4EX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZORgJlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ycFLYzlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sYvUyIQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SPxXdTlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eopIPJBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_288rM9zF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e8MltLAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P9OD8i7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K3OC1Mkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3ITPq11s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7xBL0oiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vcEtxGqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zhQEathA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rkGp22e7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Yr2391Mz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dLKVsLrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qHmgv4bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dX5mXept_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JcUVwEdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GsIeOS1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iTYqQ90F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZ0H4O5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pKIjZQdY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K2hnAnNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZOt7PfeV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjpLSyHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MWj2uXEf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3iAMkTU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tz9ttxpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ipTVAK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_01bFNJtf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3DgJ1Dge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jZONJghd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OSisgjqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GjvXKp7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qvLyCfjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W61BDa1L_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8hQKG6PP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u4OXlDc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hObIsE3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cAbINdnE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_bBLa1es8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0hDZSxUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_waqfULV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gavp75GB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cuo4kyHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v5xcYwuJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Y4SAMxOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xCd2A3Bk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_w6YL4GvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3dbqqcIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vDZ2qvEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t8ufB5Ws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aY8hiWZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_APvlu2Ca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YLApri2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GaZIwVeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6nuorEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Gle4CPH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ze5a4Zdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hvpyLEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RPcQICiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3nOLTfYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ayhZGsjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tMPUtY7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kuO9k1QY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yk2hVNHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_anRal5jD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kQw2mUTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lqmofLIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hakhiMd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KndyxLDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WfMs282q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_at3UjYuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l1y8xJsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MrVrOBde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCBd9GhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zByGvYo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ks8w4kQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jqSxoDSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DZsDZZDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGFT6mbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fYQgc4Fp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LTwkTq8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_93jo4rzg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c5u7juL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aCpy6Czc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iCXYnraP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TSgGMSsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JmGfLbi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qsZqrkEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zC3HCOMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Kaon9Wo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6k8ZbUYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jeIJaxNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vaFoU2RJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPyQnJxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0FooHsvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgbSRQjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mFL895Pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dySlfo9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_duPQYBN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PM3UYxDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yT2A16bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1OVHkqu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vVSEOBIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qP9zIZyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a29RArI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2p49K2WG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ErIwUjIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bQQwlrmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RM4Vs1yD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VMOZLb8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K1csMZcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wQP59lUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NigrsxBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1HSGBFFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZmcuWLKu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fxbg9B6F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VDYmvJSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jqk1glPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_99K1KEfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0MQjdPSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NY9uOqWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DW30KSgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WrHvATdO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vs6CrqKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TJ97074X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5JtTDLU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dzY58SSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5svgrW9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nimFLDXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dThTGe3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cJnlfFTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jJPI72L2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QWGaKjmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JThRbZ0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZEyAIOVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zyDCkZXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V3l9XpfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SjGCl5kE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hNIgtwAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LTV7O23b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fxreq2Wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaeSiw9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xbg0tDml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vP4ELeRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qfznwq6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8OXjdTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLWC0D1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZeAwbZ8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YWKGLpIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aPJKHxDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zmXysjRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bZ66Tk64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ss139Brc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0NYMaF4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LziK25Hl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V8zkkznb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wdd2G3Et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LVmquNc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tJuaZCNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mmsO7V9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RhBBHhVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g314zROa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uekW4EF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1tB8mkiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dkrQQhfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5AItNlsq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QXOwGfWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SP4VrDDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dU48VkBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EUcKrsQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8vv1vAMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KbG9kpXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g3OjWqVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C0Mtg37S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xLED02Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rptLctvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GGE1rYHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vMiF9CZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Aq97YVZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ysInfeb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IKjrDhNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_obPOaaS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3bwh05Pe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C5JtRR4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iNvzc6ng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NYNS9cHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2e0wooJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jSsVMAkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WTJ8asky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ngg6fPPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H63WMRnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZyZUq8Rs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AwF8gxmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BPZf0iUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zXv8Vqv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f6D2liZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_os1mP0ud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WOWdgAv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l3geWP7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CYtPaMi8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5G9MeVwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4GDX6aiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NMAS1Hov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ESAegzcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IHP98UiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gcdgqvfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zOU84YuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mDKtjJjD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PxglJ1IV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_96i3mll5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P8kXoqrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6dw09xvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BagLKCOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UK3nS2Hm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L1QqPq7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yq7fb8FS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OCkVYhuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ilXBmEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OZoFVkkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y7f7kykY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XLG4RUdj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5CeEnGMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O3MfrEIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XbmH2VqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TsxJcyEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_d0OurzO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_J0AKLIoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QMnzi1K4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3iLcnIAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BF6MgvjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lcliy0YV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SuKJmM8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NMdE3Vbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F3ulywfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LagjwNJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_adhwj4cK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fKchspPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZsbgZ01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qyUiG8me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t7kn4plM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t5d7Qxak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZrbRUqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y1XWnGGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lSb7yYan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HsMiGMKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qxj44S9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7KAxHl4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_14piqSnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5d0Yb4t5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ucFtQlhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TTv1hd4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xk6f0uDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nCXFlwIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZBaXjGFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bkOTd8DR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLzeiZSd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzlz4Y2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBUaQnUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YKSBqOAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_S9GNAbVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tIh1ILFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5sImQbjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BNc6cQjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gCjTbnhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jm08Ue7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ho8ObUHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JcK7TNXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AHSSpYjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3LSoWQNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4lnwT8d4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TkTC5wzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dltdzulW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uvyEHYEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o7YbYXOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5nTuVJTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iz6GzvTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i0lLBXDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oZagffta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1VK5Jp01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5FZG76qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6dQ9j8vl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vVXrm9RA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qMaYPYX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ibXZOcls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BwmQReGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IXRLwWmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MCdeG37u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IT5ijEdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yW7xm8E8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iwLIv5jS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UNpqgrMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_so3UiyI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4edaiK1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lpJ6Vb9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OdqdytnH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sMTdTJjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1htbHs2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YCYkcHR9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pgZhIZ47_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tHpucITI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IEjF5kcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2p3jqe1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ca5QhBGz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_MVlAHo9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qVa5CoQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rZhlRhkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PbZtpVnt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Lawovi2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KmICst43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_62JQmJxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IRsvcwbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IvSPEiiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xZuFaIQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oVMEhdWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EVC7go8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_itNxQVcU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rFQP0xpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9Zls0i5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3WKliKVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SP3z8NMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5iA09pCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KCRanBHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSV36UQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LjoJBkcl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iBr2RG3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pf22kH4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5zRQi6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jU7So1Qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AvwQ7h4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EprHQPPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VJBSfeWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exwrcEd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMECjTXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHNUhx5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DhuAPk17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XQSWzmPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F4RxmQmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WFrUNmGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YTC278iu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c9oHdreS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hFU0TU6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5nOwQGGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_twN6zkNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tPGxm9bZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_I1Ga4EkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wZJFOTmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_U2gRpIhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4EUZVia7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w26ArSR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GmIiixRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fc3RxAIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gC5oapa9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kAdFrI8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzyDYFLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUO7CcYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UarROumA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EMOw44Vc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SxwUVp6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hffypZvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PpLBfJM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GdQNWP3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3qiV91zU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hqhscBiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mfwQ5cGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cDLS69yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SlAXkZgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUduATqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JwOXQMAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y7yUBnAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6HtiuIQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_brr7eJwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M936CRPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xTW90t21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HwxiofVP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_umhoZyBt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_svQ51OgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_No56bynr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nfaXT7Zi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLx2nTGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XBseY77H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8uedErER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NoPJ0DBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_waQlQwxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YEmI39Z6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xbwjmURA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OeH0NcPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8S1godJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wvtLlJ8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BuLklvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H1i6FBWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8AhZXRTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3HJ5kP8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kcGPuV9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K5PwU1DF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KSO09gKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2b620S50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8vTdyCDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_00j7h9p8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_W2E8crIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rvbn1CNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jTZ6PQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zGzNEn6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8oTOyeQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VHBjb1jP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RDuytCyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yIj6C68J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m2Pzixct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cl6eqrT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExzK2ek1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lXBkMMUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZilR58xo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1z98ZNGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KBx6PJOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_unX1HTM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t1RHbxFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y3PBmuBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V89rpWb5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e7qYSrbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_92kT11Kj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G6xV0h1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MZBic8FK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OgQKp9cH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kCWmTIwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7RneCbWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Sb8kWwks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DfPu5u1D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b3DPmFZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LrwDy1Vq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1K9icLL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnbMs8yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VN8z1NAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5OqTgBPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20sEGvi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZjyutEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c0X3JU83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gfkQWoDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PaBtKyQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pNnco1X9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z5nnGnWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YXsR1GdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OSz7X4sZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k4vpay0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kvRTuGWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7VOO5def_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wbEOvKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dkzEWcHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8zgCB3wC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a5FCRwF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CTBr7ygQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zlbcSfxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vkabla4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bYaLYfgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b1k6PHwH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FypXKrdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bbjVSl94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iBcrUfhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ur3wpaMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pN5VE2Uc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KZDehmxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BDfzcS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLtJowY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5j3lMXQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g4YpgaIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U2hgCqtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LoNEV675_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DfjfzTGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MkjEK34V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LNeBWfIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TMjZXxLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5M9D25D8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5JVf2oYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q843MS6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9MqmtuQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kd5KDUuy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yhGPKUfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rdLdqnRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J0FA6pmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ylRHr95a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GijI2T6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ut9PcNCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uccj9LXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2LCh0U3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0qD5yVgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MhhaPAlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7EYcwG0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ySe6m5TS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aNZSQp4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kITzeKzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1aVOd1PC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_77BDfbso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJDehcUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EBgPRp3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9XPXS61J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10y5soes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0XFxbWId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SHjYHh7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w84TYIsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KJQvPHLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rGVI0L3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QDENlJVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_03QwaDXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jl8MVL6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fU2uxrWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RxtAxjEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cdU2sp5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_loG2AA6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FXgKrW2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BMEtN8kJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qrDkEgow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZAOTSyX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_poA8csgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zmBa1npv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QI9rTeql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jiUip2dO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kX19EfPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HPkYTAuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TuBkdKGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c7LT8YBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_y2elEdvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E87M2CQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QSB3E3FV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CK9HB9nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wFw3T7ib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yNfehG6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lItdxfh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kipCmF50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bNQ8BcJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1EKXvoDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_57Lmdx8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ND4naeco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_94jPXDir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zd5tUabP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ugLO0mks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CCLh7yUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dbe6OoTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hsCASmsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_aynAEb8C;
  SignalLine sLine_hlApwzOz;
  SignalLine sLine_gIYaub3a;
  SignalLine sLine_iYO4U9Np;
  SignalLine sLine_PH8Hqmvh;
  SignalBiquad sBiquad_s_PZaULxzs;
  SignalLine sLine_V3spw9cM;
  SignalLine sLine_nLdyUjSb;
  SignalLine sLine_KYvrgQlD;
  SignalLine sLine_iAvWVcrz;
  SignalBiquad sBiquad_s_a0XuTXEg;
  SignalLine sLine_ijS71e7X;
  SignalLine sLine_9d9rS7On;
  SignalLine sLine_Wzb8va57;
  SignalLine sLine_Mc8UP7ku;
  SignalLine sLine_nFvjXvJu;
  SignalBiquad sBiquad_s_JBQrd8RY;
  SignalLine sLine_88m0XVni;
  SignalLine sLine_jqLi9QM8;
  SignalLine sLine_LUcGbCh0;
  SignalLine sLine_49yy14gq;
  SignalLine sLine_nlkCGVGD;
  SignalBiquad sBiquad_s_lB3PrM5d;
  SignalLine sLine_cs164SZm;
  SignalLine sLine_DmvR6kcV;
  SignalLine sLine_Ckfg0tEU;
  SignalLine sLine_zkE7rwvY;
  SignalBiquad sBiquad_s_cOxCk2SY;
  SignalLine sLine_Ph5wz5wv;
  SignalLine sLine_wekJjeWu;
  SignalLine sLine_rE1aCwPP;
  SignalLine sLine_oOZq4vOK;
  SignalLine sLine_DFGY3RVD;
  SignalBiquad sBiquad_s_xGodU9nS;
  ControlVar cVar_nBIGzMcK;
  ControlVar cVar_jIeXkevX;
  ControlVar cVar_6AaoZo3A;
  ControlVar cVar_zd2aB6k7;
  ControlSlice cSlice_blSeE2n0;
  ControlVar cVar_jXKnrMvd;
  ControlVar cVar_oUOcS75y;
  ControlIf cIf_LirEINOm;
  ControlIf cIf_0mYtLwHL;
  ControlBinop cBinop_BEl6I1QO;
  ControlBinop cBinop_Wq1HkfCQ;
  ControlBinop cBinop_x7EKmf7D;
  ControlBinop cBinop_1i4k6pue;
  ControlBinop cBinop_74PpA4qw;
  ControlIf cIf_6vMWDlon;
  ControlBinop cBinop_pgqGWJ7S;
  ControlBinop cBinop_vmsUHGuv;
  ControlBinop cBinop_O6oUKQGz;
  ControlBinop cBinop_rWTnwVBA;
  ControlBinop cBinop_u4p6tqha;
  ControlVar cVar_KMNrn3Uk;
  ControlIf cIf_9oTgeodF;
  ControlIf cIf_EMdcMm3j;
  ControlBinop cBinop_j5OmVygd;
  ControlBinop cBinop_mZRkGj2C;
  ControlBinop cBinop_d9iYN5Fd;
  ControlBinop cBinop_iVcJ3haH;
  ControlBinop cBinop_pZORgJlY;
  ControlIf cIf_ycFLYzlL;
  ControlBinop cBinop_sYvUyIQQ;
  ControlBinop cBinop_SPxXdTlG;
  ControlBinop cBinop_288rM9zF;
  ControlBinop cBinop_e8MltLAB;
  ControlBinop cBinop_P9OD8i7F;
  ControlVar cVar_zhQEathA;
  ControlIf cIf_rkGp22e7;
  ControlIf cIf_Yr2391Mz;
  ControlBinop cBinop_qHmgv4bc;
  ControlBinop cBinop_dX5mXept;
  ControlBinop cBinop_iTYqQ90F;
  ControlBinop cBinop_pZ0H4O5b;
  ControlBinop cBinop_K2hnAnNp;
  ControlIf cIf_ZOt7PfeV;
  ControlBinop cBinop_mjpLSyHW;
  ControlBinop cBinop_MWj2uXEf;
  ControlBinop cBinop_tz9ttxpH;
  ControlBinop cBinop_3ipTVAK5;
  ControlBinop cBinop_01bFNJtf;
  ControlIf cIf_qvLyCfjb;
  ControlSlice cSlice_8hQKG6PP;
  ControlVar cVar_u4OXlDc6;
  ControlSlice cSlice_bBLa1es8;
  ControlVar cVar_0hDZSxUS;
  ControlSlice cSlice_cuo4kyHp;
  ControlVar cVar_v5xcYwuJ;
  ControlSlice cSlice_w6YL4GvF;
  ControlVar cVar_3dbqqcIP;
  ControlBinop cBinop_RPcQICiQ;
  ControlBinop cBinop_ayhZGsjc;
  ControlBinop cBinop_tMPUtY7z;
  ControlBinop cBinop_anRal5jD;
  ControlBinop cBinop_kQw2mUTv;
  ControlBinop cBinop_lqmofLIr;
  ControlBinop cBinop_hakhiMd8;
  ControlBinop cBinop_KndyxLDc;
  ControlVar cVar_WfMs282q;
  ControlBinop cBinop_at3UjYuv;
  ControlBinop cBinop_l1y8xJsX;
  ControlBinop cBinop_MrVrOBde;
  ControlBinop cBinop_BCBd9GhJ;
  ControlBinop cBinop_zByGvYo5;
  ControlBinop cBinop_Ks8w4kQm;
  ControlBinop cBinop_jqSxoDSb;
  ControlBinop cBinop_fGFT6mbU;
  ControlVar cVar_fYQgc4Fp;
  ControlVar cVar_LTwkTq8d;
  ControlBinop cBinop_qsZqrkEc;
  ControlBinop cBinop_zC3HCOMj;
  ControlBinop cBinop_7Kaon9Wo;
  ControlBinop cBinop_jeIJaxNH;
  ControlBinop cBinop_vaFoU2RJ;
  ControlBinop cBinop_sPyQnJxu;
  ControlBinop cBinop_0FooHsvm;
  ControlBinop cBinop_YgbSRQjV;
  ControlBinop cBinop_mFL895Pf;
  ControlBinop cBinop_Fxbg9B6F;
  ControlBinop cBinop_jqk1glPX;
  ControlBinop cBinop_99K1KEfI;
  ControlBinop cBinop_DW30KSgG;
  ControlBinop cBinop_WrHvATdO;
  ControlBinop cBinop_Vs6CrqKc;
  ControlBinop cBinop_TJ97074X;
  ControlBinop cBinop_5JtTDLU3;
  ControlBinop cBinop_dzY58SSc;
  ControlBinop cBinop_5svgrW9R;
  ControlBinop cBinop_dThTGe3g;
  ControlVar cVar_cJnlfFTt;
  ControlVar cVar_jJPI72L2;
  ControlVar cVar_QWGaKjmH;
  ControlBinop cBinop_LTV7O23b;
  ControlBinop cBinop_fxreq2Wk;
  ControlBinop cBinop_BaeSiw9W;
  ControlBinop cBinop_vP4ELeRb;
  ControlBinop cBinop_Qfznwq6N;
  ControlBinop cBinop_k8OXjdTn;
  ControlBinop cBinop_lLWC0D1E;
  ControlBinop cBinop_ZeAwbZ8Q;
  ControlBinop cBinop_5AItNlsq;
  ControlBinop cBinop_SP4VrDDG;
  ControlBinop cBinop_dU48VkBM;
  ControlBinop cBinop_KbG9kpXD;
  ControlBinop cBinop_g3OjWqVt;
  ControlBinop cBinop_C0Mtg37S;
  ControlBinop cBinop_xLED02Bg;
  ControlBinop cBinop_rptLctvF;
  ControlBinop cBinop_vMiF9CZw;
  ControlBinop cBinop_ysInfeb7;
  ControlBinop cBinop_IKjrDhNv;
  ControlBinop cBinop_3bwh05Pe;
  ControlBinop cBinop_C5JtRR4M;
  ControlBinop cBinop_iNvzc6ng;
  ControlBinop cBinop_2e0wooJ0;
  ControlVar cVar_jSsVMAkF;
  ControlVar cVar_WTJ8asky;
  ControlVar cVar_ngg6fPPs;
  ControlBinop cBinop_os1mP0ud;
  ControlBinop cBinop_WOWdgAv9;
  ControlBinop cBinop_l3geWP7T;
  ControlBinop cBinop_5G9MeVwz;
  ControlBinop cBinop_4GDX6aiQ;
  ControlBinop cBinop_NMAS1Hov;
  ControlBinop cBinop_ESAegzcC;
  ControlBinop cBinop_IHP98UiL;
  ControlBinop cBinop_Gcdgqvfy;
  ControlBinop cBinop_OCkVYhuR;
  ControlBinop cBinop_OZoFVkkP;
  ControlBinop cBinop_Y7f7kykY;
  SignalVarf sVarf_CMCY7tRq;
  SignalVarf sVarf_oA8nObyB;
  SignalVarf sVarf_hDI3n8ti;
  ControlSlice cSlice_5CeEnGMD;
  ControlVar cVar_O3MfrEIQ;
  ControlVar cVar_TsxJcyEA;
  ControlIf cIf_d0OurzO8;
  ControlIf cIf_J0AKLIoY;
  ControlBinop cBinop_3iLcnIAE;
  ControlBinop cBinop_BF6MgvjK;
  ControlBinop cBinop_NMdE3Vbt;
  ControlBinop cBinop_F3ulywfB;
  ControlBinop cBinop_adhwj4cK;
  ControlIf cIf_fKchspPB;
  ControlBinop cBinop_TZsbgZ01;
  ControlBinop cBinop_qyUiG8me;
  ControlBinop cBinop_t5d7Qxak;
  ControlBinop cBinop_TZrbRUqO;
  ControlBinop cBinop_y1XWnGGe;
  ControlVar cVar_14piqSnu;
  ControlIf cIf_5d0Yb4t5;
  ControlIf cIf_ucFtQlhR;
  ControlBinop cBinop_xk6f0uDO;
  ControlBinop cBinop_nCXFlwIW;
  ControlBinop cBinop_SLzeiZSd;
  ControlBinop cBinop_nzlz4Y2Q;
  ControlBinop cBinop_YKSBqOAZ;
  ControlIf cIf_S9GNAbVA;
  ControlBinop cBinop_tIh1ILFw;
  ControlBinop cBinop_5sImQbjs;
  ControlBinop cBinop_gCjTbnhL;
  ControlBinop cBinop_jm08Ue7l;
  ControlBinop cBinop_ho8ObUHu;
  ControlVar cVar_TkTC5wzf;
  ControlIf cIf_dltdzulW;
  ControlIf cIf_uvyEHYEe;
  ControlBinop cBinop_5nTuVJTS;
  ControlBinop cBinop_iz6GzvTO;
  ControlBinop cBinop_1VK5Jp01;
  ControlBinop cBinop_5FZG76qt;
  ControlBinop cBinop_vVXrm9RA;
  ControlIf cIf_qMaYPYX1;
  ControlBinop cBinop_ibXZOcls;
  ControlBinop cBinop_BwmQReGk;
  ControlBinop cBinop_MCdeG37u;
  ControlBinop cBinop_IT5ijEdQ;
  ControlBinop cBinop_yW7xm8E8;
  ControlIf cIf_lpJ6Vb9D;
  ControlSlice cSlice_sMTdTJjc;
  ControlVar cVar_1htbHs2G;
  ControlSlice cSlice_tHpucITI;
  ControlVar cVar_IEjF5kcn;
  ControlSlice cSlice_MVlAHo9q;
  ControlVar cVar_qVa5CoQT;
  ControlSlice cSlice_Lawovi2j;
  ControlVar cVar_KmICst43;
  ControlBinop cBinop_SP3z8NMo;
  ControlBinop cBinop_KCRanBHV;
  ControlBinop cBinop_GSV36UQF;
  ControlBinop cBinop_pf22kH4h;
  ControlBinop cBinop_L5zRQi6r;
  ControlBinop cBinop_jU7So1Qm;
  ControlBinop cBinop_AvwQ7h4q;
  ControlBinop cBinop_EprHQPPO;
  ControlVar cVar_VJBSfeWy;
  ControlBinop cBinop_exwrcEd1;
  ControlBinop cBinop_yMECjTXz;
  ControlBinop cBinop_jHNUhx5l;
  ControlBinop cBinop_DhuAPk17;
  ControlBinop cBinop_XQSWzmPf;
  ControlBinop cBinop_F4RxmQmm;
  ControlBinop cBinop_WFrUNmGN;
  ControlBinop cBinop_c9oHdreS;
  ControlVar cVar_hFU0TU6g;
  ControlVar cVar_5nOwQGGq;
  ControlBinop cBinop_w26ArSR4;
  ControlBinop cBinop_GmIiixRk;
  ControlBinop cBinop_Fc3RxAIE;
  ControlBinop cBinop_kAdFrI8I;
  ControlBinop cBinop_nzyDYFLe;
  ControlBinop cBinop_rUO7CcYm;
  ControlBinop cBinop_UarROumA;
  ControlBinop cBinop_EMOw44Vc;
  ControlBinop cBinop_SxwUVp6a;
  ControlBinop cBinop_No56bynr;
  ControlBinop cBinop_SLx2nTGJ;
  ControlBinop cBinop_XBseY77H;
  ControlBinop cBinop_waQlQwxF;
  ControlBinop cBinop_YEmI39Z6;
  ControlBinop cBinop_xbwjmURA;
  ControlBinop cBinop_OeH0NcPt;
  ControlBinop cBinop_8S1godJ6;
  ControlBinop cBinop_wvtLlJ8U;
  ControlBinop cBinop_9BuLklvu;
  ControlBinop cBinop_8AhZXRTB;
  ControlVar cVar_3HJ5kP8w;
  ControlVar cVar_kcGPuV9D;
  ControlVar cVar_K5PwU1DF;
  ControlBinop cBinop_0jTZ6PQr;
  ControlBinop cBinop_zGzNEn6W;
  ControlBinop cBinop_8oTOyeQu;
  ControlBinop cBinop_RDuytCyo;
  ControlBinop cBinop_yIj6C68J;
  ControlBinop cBinop_m2Pzixct;
  ControlBinop cBinop_Cl6eqrT4;
  ControlBinop cBinop_ExzK2ek1;
  ControlBinop cBinop_b3DPmFZJ;
  ControlBinop cBinop_1K9icLL2;
  ControlBinop cBinop_mnbMs8yr;
  ControlBinop cBinop_20sEGvi7;
  ControlBinop cBinop_qZjyutEu;
  ControlBinop cBinop_c0X3JU83;
  ControlBinop cBinop_gfkQWoDw;
  ControlBinop cBinop_PaBtKyQD;
  ControlBinop cBinop_Z5nnGnWY;
  ControlBinop cBinop_OSz7X4sZ;
  ControlBinop cBinop_k4vpay0t;
  ControlBinop cBinop_7VOO5def;
  ControlBinop cBinop_3wbEOvKO;
  ControlBinop cBinop_dkzEWcHV;
  ControlBinop cBinop_a5FCRwF4;
  ControlVar cVar_CTBr7ygQ;
  ControlVar cVar_zlbcSfxx;
  ControlVar cVar_vkabla4X;
  ControlBinop cBinop_pN5VE2Uc;
  ControlBinop cBinop_KZDehmxK;
  ControlBinop cBinop_9BDfzcS6;
  ControlBinop cBinop_5j3lMXQy;
  ControlBinop cBinop_g4YpgaIH;
  ControlBinop cBinop_U2hgCqtd;
  ControlBinop cBinop_LoNEV675;
  ControlBinop cBinop_DfjfzTGD;
  ControlBinop cBinop_MkjEK34V;
  ControlBinop cBinop_ylRHr95a;
  ControlBinop cBinop_ut9PcNCf;
  ControlBinop cBinop_uccj9LXB;
  SignalVarf sVarf_unnWmTAL;
  SignalVarf sVarf_4hr1OybL;
  SignalVarf sVarf_I5XPkGFU;
  ControlVar cVar_2LCh0U3M;
  ControlVar cVar_0qD5yVgc;
  ControlBinop cBinop_1aVOd1PC;
  ControlBinop cBinop_77BDfbso;
  ControlBinop cBinop_WJDehcUc;
  ControlBinop cBinop_9XPXS61J;
  ControlBinop cBinop_10y5soes;
  ControlBinop cBinop_0XFxbWId;
  ControlBinop cBinop_SHjYHh7s;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
