/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_aynAEb8C);
  numBytes += sLine_init(&sLine_hlApwzOz);
  numBytes += sLine_init(&sLine_gIYaub3a);
  numBytes += sLine_init(&sLine_iYO4U9Np);
  numBytes += sLine_init(&sLine_PH8Hqmvh);
  numBytes += sBiquad_init(&sBiquad_s_PZaULxzs);
  numBytes += sLine_init(&sLine_V3spw9cM);
  numBytes += sLine_init(&sLine_nLdyUjSb);
  numBytes += sLine_init(&sLine_KYvrgQlD);
  numBytes += sLine_init(&sLine_iAvWVcrz);
  numBytes += sBiquad_init(&sBiquad_s_a0XuTXEg);
  numBytes += sLine_init(&sLine_ijS71e7X);
  numBytes += sLine_init(&sLine_9d9rS7On);
  numBytes += sLine_init(&sLine_Wzb8va57);
  numBytes += sLine_init(&sLine_Mc8UP7ku);
  numBytes += sLine_init(&sLine_nFvjXvJu);
  numBytes += sBiquad_init(&sBiquad_s_JBQrd8RY);
  numBytes += sLine_init(&sLine_88m0XVni);
  numBytes += sLine_init(&sLine_jqLi9QM8);
  numBytes += sLine_init(&sLine_LUcGbCh0);
  numBytes += sLine_init(&sLine_49yy14gq);
  numBytes += sLine_init(&sLine_nlkCGVGD);
  numBytes += sBiquad_init(&sBiquad_s_lB3PrM5d);
  numBytes += sLine_init(&sLine_cs164SZm);
  numBytes += sLine_init(&sLine_DmvR6kcV);
  numBytes += sLine_init(&sLine_Ckfg0tEU);
  numBytes += sLine_init(&sLine_zkE7rwvY);
  numBytes += sBiquad_init(&sBiquad_s_cOxCk2SY);
  numBytes += sLine_init(&sLine_Ph5wz5wv);
  numBytes += sLine_init(&sLine_wekJjeWu);
  numBytes += sLine_init(&sLine_rE1aCwPP);
  numBytes += sLine_init(&sLine_oOZq4vOK);
  numBytes += sLine_init(&sLine_DFGY3RVD);
  numBytes += sBiquad_init(&sBiquad_s_xGodU9nS);
  numBytes += cVar_init_f(&cVar_nBIGzMcK, 0.0f);
  numBytes += cVar_init_f(&cVar_jIeXkevX, 0.0f);
  numBytes += cVar_init_f(&cVar_6AaoZo3A, 0.0f);
  numBytes += cVar_init_f(&cVar_zd2aB6k7, 0.0f);
  numBytes += cSlice_init(&cSlice_blSeE2n0, 1, -1);
  numBytes += cVar_init_f(&cVar_jXKnrMvd, 1337.0f);
  numBytes += cVar_init_f(&cVar_oUOcS75y, 0.0f);
  numBytes += cIf_init(&cIf_LirEINOm, false);
  numBytes += cIf_init(&cIf_0mYtLwHL, false);
  numBytes += cBinop_init(&cBinop_BEl6I1QO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6vMWDlon, false);
  numBytes += cBinop_init(&cBinop_O6oUKQGz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_rWTnwVBA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_u4p6tqha, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KMNrn3Uk, 0.0f);
  numBytes += cIf_init(&cIf_9oTgeodF, false);
  numBytes += cIf_init(&cIf_EMdcMm3j, false);
  numBytes += cBinop_init(&cBinop_j5OmVygd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ycFLYzlL, false);
  numBytes += cBinop_init(&cBinop_288rM9zF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_e8MltLAB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_P9OD8i7F, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_zhQEathA, 0.0f);
  numBytes += cIf_init(&cIf_rkGp22e7, false);
  numBytes += cIf_init(&cIf_Yr2391Mz, false);
  numBytes += cBinop_init(&cBinop_qHmgv4bc, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZOt7PfeV, false);
  numBytes += cBinop_init(&cBinop_tz9ttxpH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3ipTVAK5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_01bFNJtf, -15.0f); // __eq
  numBytes += cIf_init(&cIf_qvLyCfjb, false);
  numBytes += cSlice_init(&cSlice_8hQKG6PP, 1, -1);
  numBytes += cVar_init_f(&cVar_u4OXlDc6, 0.0f);
  numBytes += cSlice_init(&cSlice_bBLa1es8, 1, -1);
  numBytes += cVar_init_f(&cVar_0hDZSxUS, 0.0f);
  numBytes += cSlice_init(&cSlice_cuo4kyHp, 1, -1);
  numBytes += cVar_init_f(&cVar_v5xcYwuJ, 0.0f);
  numBytes += cSlice_init(&cSlice_w6YL4GvF, 1, -1);
  numBytes += cVar_init_f(&cVar_3dbqqcIP, 0.313f);
  numBytes += cBinop_init(&cBinop_ayhZGsjc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tMPUtY7z, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WfMs282q, 0.0f);
  numBytes += cVar_init_f(&cVar_fYQgc4Fp, 1337.0f);
  numBytes += cVar_init_f(&cVar_LTwkTq8d, 0.3f);
  numBytes += cBinop_init(&cBinop_zC3HCOMj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vaFoU2RJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sPyQnJxu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0FooHsvm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YgbSRQjV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mFL895Pf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jqk1glPX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_99K1KEfI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cJnlfFTt, 0.0f);
  numBytes += cVar_init_f(&cVar_jJPI72L2, 1337.0f);
  numBytes += cVar_init_f(&cVar_QWGaKjmH, 0.313f);
  numBytes += cBinop_init(&cBinop_fxreq2Wk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qfznwq6N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k8OXjdTn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lLWC0D1E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZeAwbZ8Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SP4VrDDG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dU48VkBM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jSsVMAkF, 0.0f);
  numBytes += cVar_init_f(&cVar_WTJ8asky, 1037.0f);
  numBytes += cVar_init_f(&cVar_ngg6fPPs, 0.4f);
  numBytes += cBinop_init(&cBinop_WOWdgAv9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4GDX6aiQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NMAS1Hov, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ESAegzcC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IHP98UiL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gcdgqvfy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CMCY7tRq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oA8nObyB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hDI3n8ti, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_5CeEnGMD, 1, -1);
  numBytes += cVar_init_f(&cVar_O3MfrEIQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_TsxJcyEA, 0.0f);
  numBytes += cIf_init(&cIf_d0OurzO8, false);
  numBytes += cIf_init(&cIf_J0AKLIoY, false);
  numBytes += cBinop_init(&cBinop_3iLcnIAE, 0.0f); // __pow
  numBytes += cIf_init(&cIf_fKchspPB, false);
  numBytes += cBinop_init(&cBinop_t5d7Qxak, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TZrbRUqO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_y1XWnGGe, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_14piqSnu, 0.0f);
  numBytes += cIf_init(&cIf_5d0Yb4t5, false);
  numBytes += cIf_init(&cIf_ucFtQlhR, false);
  numBytes += cBinop_init(&cBinop_xk6f0uDO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_S9GNAbVA, false);
  numBytes += cBinop_init(&cBinop_gCjTbnhL, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jm08Ue7l, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ho8ObUHu, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_TkTC5wzf, 0.0f);
  numBytes += cIf_init(&cIf_dltdzulW, false);
  numBytes += cIf_init(&cIf_uvyEHYEe, false);
  numBytes += cBinop_init(&cBinop_5nTuVJTS, 0.0f); // __pow
  numBytes += cIf_init(&cIf_qMaYPYX1, false);
  numBytes += cBinop_init(&cBinop_MCdeG37u, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IT5ijEdQ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yW7xm8E8, -15.0f); // __eq
  numBytes += cIf_init(&cIf_lpJ6Vb9D, false);
  numBytes += cSlice_init(&cSlice_sMTdTJjc, 1, -1);
  numBytes += cVar_init_f(&cVar_1htbHs2G, 0.0f);
  numBytes += cSlice_init(&cSlice_tHpucITI, 1, -1);
  numBytes += cVar_init_f(&cVar_IEjF5kcn, 0.0f);
  numBytes += cSlice_init(&cSlice_MVlAHo9q, 1, -1);
  numBytes += cVar_init_f(&cVar_qVa5CoQT, 0.0f);
  numBytes += cSlice_init(&cSlice_Lawovi2j, 1, -1);
  numBytes += cVar_init_f(&cVar_KmICst43, 0.313f);
  numBytes += cBinop_init(&cBinop_KCRanBHV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GSV36UQF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VJBSfeWy, 0.0f);
  numBytes += cVar_init_f(&cVar_hFU0TU6g, 1337.0f);
  numBytes += cVar_init_f(&cVar_5nOwQGGq, 0.3f);
  numBytes += cBinop_init(&cBinop_GmIiixRk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nzyDYFLe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rUO7CcYm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UarROumA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EMOw44Vc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SxwUVp6a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SLx2nTGJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XBseY77H, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3HJ5kP8w, 0.0f);
  numBytes += cVar_init_f(&cVar_kcGPuV9D, 1337.0f);
  numBytes += cVar_init_f(&cVar_K5PwU1DF, 0.313f);
  numBytes += cBinop_init(&cBinop_zGzNEn6W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yIj6C68J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m2Pzixct, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Cl6eqrT4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ExzK2ek1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1K9icLL2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mnbMs8yr, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_CTBr7ygQ, 0.0f);
  numBytes += cVar_init_f(&cVar_zlbcSfxx, 1037.0f);
  numBytes += cVar_init_f(&cVar_vkabla4X, 0.4f);
  numBytes += cBinop_init(&cBinop_KZDehmxK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_g4YpgaIH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U2hgCqtd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LoNEV675, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DfjfzTGD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MkjEK34V, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_unnWmTAL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4hr1OybL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I5XPkGFU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2LCh0U3M, 5705.6f);
  numBytes += cVar_init_f(&cVar_0qD5yVgc, 313.3f);
  numBytes += cBinop_init(&cBinop_1aVOd1PC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_77BDfbso, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_WJDehcUc, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RxtAxjEq_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_loG2AA6K_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cdU2sp5Y_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hsCASmsE_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qrDkEgow_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZAOTSyX1_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FXgKrW2G_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BMEtN8kJ_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_poA8csgt_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kX19EfPm_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jiUip2dO_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QI9rTeql_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c7LT8YBq_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TuBkdKGw_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HPkYTAuc_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QSB3E3FV_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E87M2CQv_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y2elEdvC_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yNfehG6W_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lItdxfh1_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CK9HB9nu_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wFw3T7ib_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kipCmF50_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_57Lmdx8B_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1EKXvoDQ_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNQ8BcJL_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zd5tUabP_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_94jPXDir_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ND4naeco_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dbe6OoTL_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CCLh7yUt_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ugLO0mks_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zmBa1npv_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_nBIGzMcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w84TYIsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_jIeXkevX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJQvPHLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_6AaoZo3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rGVI0L3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_zd2aB6k7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QDENlJVz_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kITzeKzl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ySe6m5TS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aNZSQp4e_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_0dDeyIVs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_blSeE2n0, 0, m, &cSlice_blSeE2n0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gavp75GB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_blSeE2n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hfss78yL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hfss78yL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_jXKnrMvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hfss78yL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Hfss78yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FXgKrW2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_oUOcS75y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pgqGWJ7S_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LirEINOm, 0, m, &cIf_LirEINOm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_LirEINOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vmsUHGuv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_0mYtLwHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tTcZ9fyc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1i4k6pue_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Wqpjjrbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEl6I1QO, HV_BINOP_POW, 0, m, &cBinop_BEl6I1QO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BEl6I1QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vMWDlon, 0, m, &cIf_6vMWDlon_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wq1HkfCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_74PpA4qw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jw2VyW14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_x7EKmf7D_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JMuIX05c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0mYtLwHL, 0, m, &cIf_0mYtLwHL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_x7EKmf7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0mYtLwHL, 1, m, &cIf_0mYtLwHL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1i4k6pue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Wq1HkfCQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tTcZ9fyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6vMWDlon, 0, m, &cIf_6vMWDlon_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_74PpA4qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEl6I1QO, HV_BINOP_POW, 1, m, &cBinop_BEl6I1QO_sendMessage);
  cMsg_Wqpjjrbs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_6vMWDlon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CMCY7tRq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_pgqGWJ7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LirEINOm, 1, m, &cIf_LirEINOm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vmsUHGuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWTnwVBA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rWTnwVBA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u4p6tqha, HV_BINOP_EQ, 1, m, &cBinop_u4p6tqha_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bnXNb5oO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6oUKQGz, HV_BINOP_ADD, 0, m, &cBinop_O6oUKQGz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O6oUKQGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jw2VyW14_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JMuIX05c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rWTnwVBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vMWDlon, 1, m, &cIf_6vMWDlon_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_u4p6tqha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sR4Ldj2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_sR4Ldj2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CMCY7tRq, m);
}

void Heavy_WSTD_3Q::cCast_nkWKiObo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oUOcS75y, 0, m, &cVar_oUOcS75y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5JG4Eaoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6oUKQGz, HV_BINOP_ADD, 1, m, &cBinop_O6oUKQGz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWTnwVBA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rWTnwVBA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u4p6tqha, HV_BINOP_EQ, 0, m, &cBinop_u4p6tqha_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oXORB5PU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnXNb5oO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_KMNrn3Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sYvUyIQQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9oTgeodF, 0, m, &cIf_9oTgeodF_sendMessage);
}

void Heavy_WSTD_3Q::cIf_9oTgeodF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SPxXdTlG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_EMdcMm3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bRFhY4EX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iVcJ3haH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_2IUrCFxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_j5OmVygd, HV_BINOP_POW, 0, m, &cBinop_j5OmVygd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j5OmVygd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ycFLYzlL, 0, m, &cIf_ycFLYzlL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mZRkGj2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pZORgJlY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gZPIZGjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d9iYN5Fd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8SK7IoGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EMdcMm3j, 0, m, &cIf_EMdcMm3j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d9iYN5Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EMdcMm3j, 1, m, &cIf_EMdcMm3j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iVcJ3haH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mZRkGj2C_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bRFhY4EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ycFLYzlL, 0, m, &cIf_ycFLYzlL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pZORgJlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j5OmVygd, HV_BINOP_POW, 1, m, &cBinop_j5OmVygd_sendMessage);
  cMsg_2IUrCFxO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ycFLYzlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OCkVYhuR_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OZoFVkkP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Y7f7kykY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_sYvUyIQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9oTgeodF, 1, m, &cIf_9oTgeodF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SPxXdTlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8MltLAB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_e8MltLAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9OD8i7F, HV_BINOP_EQ, 1, m, &cBinop_P9OD8i7F_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eopIPJBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_288rM9zF, HV_BINOP_ADD, 0, m, &cBinop_288rM9zF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_288rM9zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gZPIZGjH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8SK7IoGb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e8MltLAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ycFLYzlL, 1, m, &cIf_ycFLYzlL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P9OD8i7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3OC1Mkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_K3OC1Mkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OCkVYhuR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OZoFVkkP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Y7f7kykY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3ITPq11s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KMNrn3Uk, 0, m, &cVar_KMNrn3Uk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7xBL0oiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eopIPJBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_vcEtxGqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_288rM9zF, HV_BINOP_ADD, 1, m, &cBinop_288rM9zF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8MltLAB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_e8MltLAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9OD8i7F, HV_BINOP_EQ, 0, m, &cBinop_P9OD8i7F_sendMessage);
}

void Heavy_WSTD_3Q::cVar_zhQEathA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mjpLSyHW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rkGp22e7, 0, m, &cIf_rkGp22e7_sendMessage);
}

void Heavy_WSTD_3Q::cIf_rkGp22e7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MWj2uXEf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Yr2391Mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pKIjZQdY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_pZ0H4O5b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_dLKVsLrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHmgv4bc, HV_BINOP_POW, 0, m, &cBinop_qHmgv4bc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qHmgv4bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZOt7PfeV, 0, m, &cIf_ZOt7PfeV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dX5mXept_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_K2hnAnNp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JcUVwEdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yr2391Mz, 0, m, &cIf_Yr2391Mz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GsIeOS1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iTYqQ90F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iTYqQ90F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yr2391Mz, 1, m, &cIf_Yr2391Mz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pZ0H4O5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dX5mXept_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pKIjZQdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZOt7PfeV, 0, m, &cIf_ZOt7PfeV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K2hnAnNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHmgv4bc, HV_BINOP_POW, 1, m, &cBinop_qHmgv4bc_sendMessage);
  cMsg_dLKVsLrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ZOt7PfeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_hDI3n8ti, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_mjpLSyHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rkGp22e7, 1, m, &cIf_rkGp22e7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MWj2uXEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ipTVAK5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3ipTVAK5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_01bFNJtf, HV_BINOP_EQ, 1, m, &cBinop_01bFNJtf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3iAMkTU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tz9ttxpH, HV_BINOP_ADD, 0, m, &cBinop_tz9ttxpH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tz9ttxpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GsIeOS1Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JcUVwEdc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3ipTVAK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZOt7PfeV, 1, m, &cIf_ZOt7PfeV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_01bFNJtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3DgJ1Dge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3DgJ1Dge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hDI3n8ti, m);
}

void Heavy_WSTD_3Q::cCast_jZONJghd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zhQEathA, 0, m, &cVar_zhQEathA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OSisgjqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3iAMkTU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_GjvXKp7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tz9ttxpH, HV_BINOP_ADD, 1, m, &cBinop_tz9ttxpH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ipTVAK5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3ipTVAK5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_01bFNJtf, HV_BINOP_EQ, 0, m, &cBinop_01bFNJtf_sendMessage);
}

void Heavy_WSTD_3Q::cIf_qvLyCfjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_oA8nObyB, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_W61BDa1L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8hQKG6PP, 0, m, &cSlice_8hQKG6PP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cAbINdnE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_8hQKG6PP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hObIsE3R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hObIsE3R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_u4OXlDc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hObIsE3R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hObIsE3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qrDkEgow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_cAbINdnE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bBLa1es8, 0, m, &cSlice_bBLa1es8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0dDeyIVs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_bBLa1es8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_waqfULV9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_waqfULV9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_0hDZSxUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_waqfULV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_waqfULV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_poA8csgt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_gavp75GB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cuo4kyHp, 0, m, &cSlice_cuo4kyHp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xCd2A3Bk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_cuo4kyHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y4SAMxOE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y4SAMxOE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_v5xcYwuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y4SAMxOE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Y4SAMxOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZAOTSyX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_xCd2A3Bk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w6YL4GvF, 0, m, &cSlice_w6YL4GvF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_w6YL4GvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vDZ2qvEM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vDZ2qvEM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_3dbqqcIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vDZ2qvEM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vDZ2qvEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BMEtN8kJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_t8ufB5Ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aynAEb8C, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aY8hiWZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hlApwzOz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_APvlu2Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gIYaub3a, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YLApri2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iYO4U9Np, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GaZIwVeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PH8Hqmvh, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_E6nuorEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Gle4CPH0_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_Gle4CPH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ayhZGsjc, HV_BINOP_DIVIDE, 1, m, &cBinop_ayhZGsjc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3nOLTfYk_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Ze5a4Zdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RPcQICiQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4hvpyLEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Ze5a4Zdu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RPcQICiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ayhZGsjc, HV_BINOP_DIVIDE, 0, m, &cBinop_ayhZGsjc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3nOLTfYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4hvpyLEG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ayhZGsjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMPUtY7z, HV_BINOP_MULTIPLY, 1, m, &cBinop_tMPUtY7z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tMPUtY7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c5u7juL8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_93jo4rzg_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_kuO9k1QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aCpy6Czc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_yk2hVNHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iCXYnraP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_anRal5jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_kQw2mUTv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kQw2mUTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMPUtY7z, HV_BINOP_MULTIPLY, 0, m, &cBinop_tMPUtY7z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lqmofLIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hakhiMd8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hakhiMd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JmGfLbi7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KndyxLDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WfMs282q, 1, m, &cVar_WfMs282q_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WfMs282q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6k8ZbUYD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_at3UjYuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vaFoU2RJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_vaFoU2RJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l1y8xJsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_at3UjYuv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MrVrOBde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BCBd9GhJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BCBd9GhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPyQnJxu, HV_BINOP_MULTIPLY, 1, m, &cBinop_sPyQnJxu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zByGvYo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FooHsvm, HV_BINOP_MULTIPLY, 1, m, &cBinop_0FooHsvm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ks8w4kQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zByGvYo5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jqSxoDSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgbSRQjV, HV_BINOP_MULTIPLY, 1, m, &cBinop_YgbSRQjV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DZsDZZDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fGFT6mbU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fGFT6mbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mFL895Pf, HV_BINOP_MULTIPLY, 1, m, &cBinop_mFL895Pf_sendMessage);
}

void Heavy_WSTD_3Q::cVar_fYQgc4Fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ErIwUjIM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_anRal5jD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2p49K2WG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_LTwkTq8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lqmofLIr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_93jo4rzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_yk2hVNHW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_c5u7juL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kuO9k1QY_sendMessage);
}

void Heavy_WSTD_3Q::cSend_aCpy6Czc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QI9rTeql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iCXYnraP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jiUip2dO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_TSgGMSsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kX19EfPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JmGfLbi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qsZqrkEc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qsZqrkEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zC3HCOMj, HV_BINOP_MULTIPLY, 1, m, &cBinop_zC3HCOMj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zC3HCOMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7Kaon9Wo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7Kaon9Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TSgGMSsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_6k8ZbUYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jeIJaxNH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jeIJaxNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1OVHkqu0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vVSEOBIk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qP9zIZyH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PM3UYxDp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a29RArI3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yT2A16bw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vaFoU2RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t8ufB5Ws_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sPyQnJxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aY8hiWZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0FooHsvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_APvlu2Ca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YgbSRQjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YLApri2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mFL895Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GaZIwVeA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_dySlfo9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LTwkTq8d, 1, m, &cVar_LTwkTq8d_sendMessage);
}

void Heavy_WSTD_3Q::cCast_duPQYBN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fYQgc4Fp, 0, m, &cVar_fYQgc4Fp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PM3UYxDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FooHsvm, HV_BINOP_MULTIPLY, 0, m, &cBinop_0FooHsvm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yT2A16bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vaFoU2RJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_vaFoU2RJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1OVHkqu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_vVSEOBIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mFL895Pf, HV_BINOP_MULTIPLY, 0, m, &cBinop_mFL895Pf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qP9zIZyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgbSRQjV, HV_BINOP_MULTIPLY, 0, m, &cBinop_YgbSRQjV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a29RArI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPyQnJxu, HV_BINOP_MULTIPLY, 0, m, &cBinop_sPyQnJxu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2p49K2WG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WfMs282q, 0, m, &cVar_WfMs282q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ErIwUjIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LTwkTq8d, 0, m, &cVar_LTwkTq8d_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bQQwlrmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V3spw9cM, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RM4Vs1yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nLdyUjSb, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VMOZLb8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KYvrgQlD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_K1csMZcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iAvWVcrz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wQP59lUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NigrsxBz_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_NigrsxBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqk1glPX, HV_BINOP_DIVIDE, 1, m, &cBinop_jqk1glPX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDYmvJSJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_1HSGBFFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Fxbg9B6F_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZmcuWLKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_1HSGBFFY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Fxbg9B6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqk1glPX, HV_BINOP_DIVIDE, 0, m, &cBinop_jqk1glPX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VDYmvJSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZmcuWLKu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jqk1glPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_99K1KEfI, HV_BINOP_MULTIPLY, 1, m, &cBinop_99K1KEfI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_99K1KEfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JThRbZ0b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZEyAIOVZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_0MQjdPSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zyDCkZXL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_NY9uOqWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V3l9XpfI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DW30KSgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WrHvATdO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WrHvATdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_99K1KEfI, HV_BINOP_MULTIPLY, 0, m, &cBinop_99K1KEfI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vs6CrqKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TJ97074X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TJ97074X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hNIgtwAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_5JtTDLU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8OXjdTn, HV_BINOP_MULTIPLY, 1, m, &cBinop_k8OXjdTn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dzY58SSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cJnlfFTt, 1, m, &cVar_cJnlfFTt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5svgrW9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLWC0D1E, HV_BINOP_MULTIPLY, 1, m, &cBinop_lLWC0D1E_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nimFLDXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dThTGe3g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dThTGe3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeAwbZ8Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZeAwbZ8Q_sendMessage);
}

void Heavy_WSTD_3Q::cVar_cJnlfFTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xbg0tDml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_jJPI72L2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zmXysjRN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_DW30KSgG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bZ66Tk64_sendMessage);
}

void Heavy_WSTD_3Q::cVar_QWGaKjmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Vs6CrqKc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JThRbZ0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0MQjdPSR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZEyAIOVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NY9uOqWN_sendMessage);
}

void Heavy_WSTD_3Q::cSend_zyDCkZXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HPkYTAuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_V3l9XpfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TuBkdKGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_SjGCl5kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c7LT8YBq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_hNIgtwAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LTV7O23b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LTV7O23b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fxreq2Wk, HV_BINOP_MULTIPLY, 1, m, &cBinop_fxreq2Wk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fxreq2Wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BaeSiw9W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BaeSiw9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SjGCl5kE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xbg0tDml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vP4ELeRb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vP4ELeRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V8zkkznb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0NYMaF4K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ss139Brc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LziK25Hl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qfznwq6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQQwlrmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_k8OXjdTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RM4Vs1yD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lLWC0D1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VMOZLb8w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZeAwbZ8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1csMZcJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_YWKGLpIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jJPI72L2, 0, m, &cVar_jJPI72L2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aPJKHxDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QWGaKjmH, 1, m, &cVar_QWGaKjmH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zmXysjRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QWGaKjmH, 0, m, &cVar_QWGaKjmH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bZ66Tk64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cJnlfFTt, 0, m, &cVar_cJnlfFTt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ss139Brc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8OXjdTn, HV_BINOP_MULTIPLY, 0, m, &cBinop_k8OXjdTn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0NYMaF4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLWC0D1E, HV_BINOP_MULTIPLY, 0, m, &cBinop_lLWC0D1E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LziK25Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfznwq6N, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qfznwq6N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V8zkkznb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeAwbZ8Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZeAwbZ8Q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_wdd2G3Et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ijS71e7X, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LVmquNc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9d9rS7On, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_tJuaZCNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wzb8va57, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_mmsO7V9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mc8UP7ku, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RhBBHhVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nFvjXvJu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_g314zROa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uekW4EF8_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_uekW4EF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SP4VrDDG, HV_BINOP_DIVIDE, 1, m, &cBinop_SP4VrDDG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QXOwGfWA_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_1tB8mkiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_5AItNlsq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dkrQQhfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_1tB8mkiT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5AItNlsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SP4VrDDG, HV_BINOP_DIVIDE, 0, m, &cBinop_SP4VrDDG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QXOwGfWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dkrQQhfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SP4VrDDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dU48VkBM, HV_BINOP_MULTIPLY, 1, m, &cBinop_dU48VkBM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dU48VkBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H63WMRnC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZyZUq8Rs_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_EUcKrsQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AwF8gxmM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_8vv1vAMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BPZf0iUR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KbG9kpXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_g3OjWqVt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g3OjWqVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dU48VkBM, HV_BINOP_MULTIPLY, 0, m, &cBinop_dU48VkBM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C0Mtg37S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_xLED02Bg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xLED02Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f6D2liZS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rptLctvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4GDX6aiQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_4GDX6aiQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GGE1rYHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vMiF9CZw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vMiF9CZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rptLctvF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Aq97YVZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ysInfeb7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ysInfeb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NMAS1Hov, HV_BINOP_MULTIPLY, 1, m, &cBinop_NMAS1Hov_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IKjrDhNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ESAegzcC, HV_BINOP_MULTIPLY, 1, m, &cBinop_ESAegzcC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_obPOaaS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3bwh05Pe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3bwh05Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IKjrDhNv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C5JtRR4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jSsVMAkF, 1, m, &cVar_jSsVMAkF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iNvzc6ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IHP98UiL, HV_BINOP_MULTIPLY, 1, m, &cBinop_IHP98UiL_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NYNS9cHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2e0wooJ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2e0wooJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gcdgqvfy, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gcdgqvfy_sendMessage);
}

void Heavy_WSTD_3Q::cVar_jSsVMAkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CYtPaMi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_WTJ8asky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yq7fb8FS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KbG9kpXD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L1QqPq7D_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ngg6fPPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_C0Mtg37S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H63WMRnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_EUcKrsQZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZyZUq8Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_8vv1vAMg_sendMessage);
}

void Heavy_WSTD_3Q::cSend_AwF8gxmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y2elEdvC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_BPZf0iUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_E87M2CQv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zXv8Vqv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QSB3E3FV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_f6D2liZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_os1mP0ud_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_os1mP0ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOWdgAv9, HV_BINOP_MULTIPLY, 1, m, &cBinop_WOWdgAv9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WOWdgAv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_l3geWP7T_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l3geWP7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zXv8Vqv4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_CYtPaMi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5G9MeVwz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5G9MeVwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_96i3mll5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UK3nS2Hm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6dw09xvV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PxglJ1IV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P8kXoqrj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BagLKCOA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4GDX6aiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdd2G3Et_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_NMAS1Hov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LVmquNc3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ESAegzcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tJuaZCNp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IHP98UiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mmsO7V9V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Gcdgqvfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RhBBHhVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_zOU84YuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ngg6fPPs, 1, m, &cVar_ngg6fPPs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mDKtjJjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WTJ8asky, 0, m, &cVar_WTJ8asky_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PxglJ1IV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ESAegzcC, HV_BINOP_MULTIPLY, 0, m, &cBinop_ESAegzcC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_96i3mll5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_P8kXoqrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NMAS1Hov, HV_BINOP_MULTIPLY, 0, m, &cBinop_NMAS1Hov_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6dw09xvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IHP98UiL, HV_BINOP_MULTIPLY, 0, m, &cBinop_IHP98UiL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BagLKCOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4GDX6aiQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_4GDX6aiQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UK3nS2Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gcdgqvfy, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gcdgqvfy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_L1QqPq7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jSsVMAkF, 0, m, &cVar_jSsVMAkF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yq7fb8FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ngg6fPPs, 0, m, &cVar_ngg6fPPs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OCkVYhuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qvLyCfjb, 1, m, &cIf_qvLyCfjb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2ilXBmEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oA8nObyB, m);
}

void Heavy_WSTD_3Q::cBinop_OZoFVkkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ilXBmEh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Y7f7kykY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qvLyCfjb, 0, m, &cIf_qvLyCfjb_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_XLG4RUdj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5CeEnGMD, 0, m, &cSlice_5CeEnGMD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ca5QhBGz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_5CeEnGMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XbmH2VqJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XbmH2VqJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_O3MfrEIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XbmH2VqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_XbmH2VqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CK9HB9nu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_TsxJcyEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TZsbgZ01_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_d0OurzO8, 0, m, &cIf_d0OurzO8_sendMessage);
}

void Heavy_WSTD_3Q::cIf_d0OurzO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qyUiG8me_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_J0AKLIoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LagjwNJV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_F3ulywfB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_QMnzi1K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3iLcnIAE, HV_BINOP_POW, 0, m, &cBinop_3iLcnIAE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3iLcnIAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKchspPB, 0, m, &cIf_fKchspPB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BF6MgvjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_adhwj4cK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lcliy0YV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0AKLIoY, 0, m, &cIf_J0AKLIoY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SuKJmM8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NMdE3Vbt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NMdE3Vbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0AKLIoY, 1, m, &cIf_J0AKLIoY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_F3ulywfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BF6MgvjK_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LagjwNJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fKchspPB, 0, m, &cIf_fKchspPB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_adhwj4cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3iLcnIAE, HV_BINOP_POW, 1, m, &cBinop_3iLcnIAE_sendMessage);
  cMsg_QMnzi1K4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_fKchspPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_unnWmTAL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_TZsbgZ01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d0OurzO8, 1, m, &cIf_d0OurzO8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qyUiG8me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZrbRUqO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_TZrbRUqO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1XWnGGe, HV_BINOP_EQ, 1, m, &cBinop_y1XWnGGe_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_t7kn4plM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5d7Qxak, HV_BINOP_ADD, 0, m, &cBinop_t5d7Qxak_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t5d7Qxak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SuKJmM8J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lcliy0YV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TZrbRUqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKchspPB, 1, m, &cIf_fKchspPB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_y1XWnGGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lSb7yYan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lSb7yYan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_unnWmTAL, m);
}

void Heavy_WSTD_3Q::cCast_HsMiGMKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TsxJcyEA, 0, m, &cVar_TsxJcyEA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qxj44S9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t7kn4plM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_7KAxHl4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5d7Qxak, HV_BINOP_ADD, 1, m, &cBinop_t5d7Qxak_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZrbRUqO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_TZrbRUqO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1XWnGGe, HV_BINOP_EQ, 0, m, &cBinop_y1XWnGGe_sendMessage);
}

void Heavy_WSTD_3Q::cVar_14piqSnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tIh1ILFw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5d0Yb4t5, 0, m, &cIf_5d0Yb4t5_sendMessage);
}

void Heavy_WSTD_3Q::cIf_5d0Yb4t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5sImQbjs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_ucFtQlhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xBUaQnUb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nzlz4Y2Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_TTv1hd4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xk6f0uDO, HV_BINOP_POW, 0, m, &cBinop_xk6f0uDO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xk6f0uDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S9GNAbVA, 0, m, &cIf_S9GNAbVA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nCXFlwIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YKSBqOAZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZBaXjGFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SLzeiZSd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bkOTd8DR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ucFtQlhR, 0, m, &cIf_ucFtQlhR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SLzeiZSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ucFtQlhR, 1, m, &cIf_ucFtQlhR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nzlz4Y2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_nCXFlwIW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xBUaQnUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_S9GNAbVA, 0, m, &cIf_S9GNAbVA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YKSBqOAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xk6f0uDO, HV_BINOP_POW, 1, m, &cBinop_xk6f0uDO_sendMessage);
  cMsg_TTv1hd4c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_S9GNAbVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ylRHr95a_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ut9PcNCf_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_uccj9LXB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_tIh1ILFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5d0Yb4t5, 1, m, &cIf_5d0Yb4t5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5sImQbjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jm08Ue7l, HV_BINOP_GREATER_THAN, 1, m, &cBinop_jm08Ue7l_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ho8ObUHu, HV_BINOP_EQ, 1, m, &cBinop_ho8ObUHu_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BNc6cQjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCjTbnhL, HV_BINOP_ADD, 0, m, &cBinop_gCjTbnhL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gCjTbnhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZBaXjGFK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bkOTd8DR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jm08Ue7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S9GNAbVA, 1, m, &cIf_S9GNAbVA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ho8ObUHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JcK7TNXy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JcK7TNXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ylRHr95a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ut9PcNCf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_uccj9LXB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AHSSpYjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_14piqSnu, 0, m, &cVar_14piqSnu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3LSoWQNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCjTbnhL, HV_BINOP_ADD, 1, m, &cBinop_gCjTbnhL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jm08Ue7l, HV_BINOP_GREATER_THAN, 0, m, &cBinop_jm08Ue7l_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ho8ObUHu, HV_BINOP_EQ, 0, m, &cBinop_ho8ObUHu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4lnwT8d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BNc6cQjL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_TkTC5wzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ibXZOcls_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dltdzulW, 0, m, &cIf_dltdzulW_sendMessage);
}

void Heavy_WSTD_3Q::cIf_dltdzulW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BwmQReGk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_uvyEHYEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6dQ9j8vl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5FZG76qt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_o7YbYXOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nTuVJTS, HV_BINOP_POW, 0, m, &cBinop_5nTuVJTS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5nTuVJTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qMaYPYX1, 0, m, &cIf_qMaYPYX1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iz6GzvTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vVXrm9RA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i0lLBXDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uvyEHYEe, 0, m, &cIf_uvyEHYEe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oZagffta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1VK5Jp01_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1VK5Jp01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uvyEHYEe, 1, m, &cIf_uvyEHYEe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5FZG76qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iz6GzvTO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6dQ9j8vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qMaYPYX1, 0, m, &cIf_qMaYPYX1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vVXrm9RA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nTuVJTS, HV_BINOP_POW, 1, m, &cBinop_5nTuVJTS_sendMessage);
  cMsg_o7YbYXOh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_qMaYPYX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_I5XPkGFU, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ibXZOcls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dltdzulW, 1, m, &cIf_dltdzulW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BwmQReGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IT5ijEdQ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_IT5ijEdQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW7xm8E8, HV_BINOP_EQ, 1, m, &cBinop_yW7xm8E8_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_IXRLwWmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCdeG37u, HV_BINOP_ADD, 0, m, &cBinop_MCdeG37u_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MCdeG37u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oZagffta_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i0lLBXDh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IT5ijEdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qMaYPYX1, 1, m, &cIf_qMaYPYX1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yW7xm8E8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iwLIv5jS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_iwLIv5jS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_I5XPkGFU, m);
}

void Heavy_WSTD_3Q::cCast_UNpqgrMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCdeG37u, HV_BINOP_ADD, 1, m, &cBinop_MCdeG37u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IT5ijEdQ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_IT5ijEdQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW7xm8E8, HV_BINOP_EQ, 0, m, &cBinop_yW7xm8E8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_so3UiyI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TkTC5wzf, 0, m, &cVar_TkTC5wzf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4edaiK1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IXRLwWmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_lpJ6Vb9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4hr1OybL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_OdqdytnH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sMTdTJjc, 0, m, &cSlice_sMTdTJjc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pgZhIZ47_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_sMTdTJjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YCYkcHR9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YCYkcHR9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_1htbHs2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YCYkcHR9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YCYkcHR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yNfehG6W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_pgZhIZ47_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tHpucITI, 0, m, &cSlice_tHpucITI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XLG4RUdj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_tHpucITI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2p3jqe1Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2p3jqe1Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_IEjF5kcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2p3jqe1Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_2p3jqe1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kipCmF50_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_Ca5QhBGz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MVlAHo9q, 0, m, &cSlice_MVlAHo9q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PbZtpVnt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_MVlAHo9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rZhlRhkS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rZhlRhkS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_qVa5CoQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rZhlRhkS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_rZhlRhkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lItdxfh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_PbZtpVnt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Lawovi2j, 0, m, &cSlice_Lawovi2j_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Lawovi2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_62JQmJxT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_62JQmJxT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_KmICst43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_62JQmJxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_62JQmJxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wFw3T7ib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IRsvcwbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_88m0XVni, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_IvSPEiiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jqLi9QM8, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xZuFaIQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUcGbCh0, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_oVMEhdWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_49yy14gq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EVC7go8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nlkCGVGD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_itNxQVcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rFQP0xpW_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_rFQP0xpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCRanBHV, HV_BINOP_DIVIDE, 1, m, &cBinop_KCRanBHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5iA09pCY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_9Zls0i5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SP3z8NMo_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3WKliKVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9Zls0i5i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SP3z8NMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCRanBHV, HV_BINOP_DIVIDE, 0, m, &cBinop_KCRanBHV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5iA09pCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3WKliKVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KCRanBHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSV36UQF, HV_BINOP_MULTIPLY, 1, m, &cBinop_GSV36UQF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GSV36UQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tPGxm9bZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_twN6zkNQ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_LjoJBkcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I1Ga4EkD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_iBr2RG3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wZJFOTmo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_pf22kH4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_L5zRQi6r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L5zRQi6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSV36UQF, HV_BINOP_MULTIPLY, 0, m, &cBinop_GSV36UQF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jU7So1Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AvwQ7h4q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AvwQ7h4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4EUZVia7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EprHQPPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VJBSfeWy, 1, m, &cVar_VJBSfeWy_sendMessage);
}

void Heavy_WSTD_3Q::cVar_VJBSfeWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gC5oapa9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_exwrcEd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nzyDYFLe, HV_BINOP_MULTIPLY, 1, m, &cBinop_nzyDYFLe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yMECjTXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_exwrcEd1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jHNUhx5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DhuAPk17_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DhuAPk17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rUO7CcYm, HV_BINOP_MULTIPLY, 1, m, &cBinop_rUO7CcYm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XQSWzmPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UarROumA, HV_BINOP_MULTIPLY, 1, m, &cBinop_UarROumA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_F4RxmQmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XQSWzmPf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WFrUNmGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMOw44Vc, HV_BINOP_MULTIPLY, 1, m, &cBinop_EMOw44Vc_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YTC278iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c9oHdreS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c9oHdreS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxwUVp6a, HV_BINOP_MULTIPLY, 1, m, &cBinop_SxwUVp6a_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hFU0TU6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JwOXQMAs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pf22kH4h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUduATqQ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5nOwQGGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_jU7So1Qm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_twN6zkNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iBr2RG3C_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tPGxm9bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_LjoJBkcl_sendMessage);
}

void Heavy_WSTD_3Q::cSend_I1Ga4EkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bNQ8BcJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wZJFOTmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1EKXvoDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_U2gRpIhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_57Lmdx8B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_4EUZVia7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_w26ArSR4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_w26ArSR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GmIiixRk, HV_BINOP_MULTIPLY, 1, m, &cBinop_GmIiixRk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GmIiixRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fc3RxAIE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Fc3RxAIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U2gRpIhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gC5oapa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kAdFrI8I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kAdFrI8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3qiV91zU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GdQNWP3J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hqhscBiL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cDLS69yw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mfwQ5cGq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SlAXkZgQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nzyDYFLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IRsvcwbS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rUO7CcYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IvSPEiiA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UarROumA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xZuFaIQz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EMOw44Vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oVMEhdWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SxwUVp6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EVC7go8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_hffypZvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5nOwQGGq, 1, m, &cVar_5nOwQGGq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PpLBfJM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hFU0TU6g, 0, m, &cVar_hFU0TU6g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GdQNWP3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxwUVp6a, HV_BINOP_MULTIPLY, 0, m, &cBinop_SxwUVp6a_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3qiV91zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_hqhscBiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMOw44Vc, HV_BINOP_MULTIPLY, 0, m, &cBinop_EMOw44Vc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mfwQ5cGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rUO7CcYm, HV_BINOP_MULTIPLY, 0, m, &cBinop_rUO7CcYm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cDLS69yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UarROumA, HV_BINOP_MULTIPLY, 0, m, &cBinop_UarROumA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SlAXkZgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nzyDYFLe, HV_BINOP_MULTIPLY, 0, m, &cBinop_nzyDYFLe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UUduATqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VJBSfeWy, 0, m, &cVar_VJBSfeWy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JwOXQMAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5nOwQGGq, 0, m, &cVar_5nOwQGGq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Y7yUBnAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cs164SZm, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6HtiuIQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DmvR6kcV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_brr7eJwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ckfg0tEU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_M936CRPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zkE7rwvY, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xTW90t21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HwxiofVP_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_HwxiofVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLx2nTGJ, HV_BINOP_DIVIDE, 1, m, &cBinop_SLx2nTGJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nfaXT7Zi_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_umhoZyBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_No56bynr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_svQ51OgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_umhoZyBt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_No56bynr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLx2nTGJ, HV_BINOP_DIVIDE, 0, m, &cBinop_SLx2nTGJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nfaXT7Zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_svQ51OgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SLx2nTGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBseY77H, HV_BINOP_MULTIPLY, 1, m, &cBinop_XBseY77H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XBseY77H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KSO09gKx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2b620S50_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_8uedErER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8vTdyCDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_NoPJ0DBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_00j7h9p8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_waQlQwxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_YEmI39Z6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YEmI39Z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBseY77H, HV_BINOP_MULTIPLY, 0, m, &cBinop_XBseY77H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xbwjmURA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OeH0NcPt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OeH0NcPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rvbn1CNd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8S1godJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2Pzixct, HV_BINOP_MULTIPLY, 1, m, &cBinop_m2Pzixct_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wvtLlJ8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3HJ5kP8w, 1, m, &cVar_3HJ5kP8w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9BuLklvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cl6eqrT4, HV_BINOP_MULTIPLY, 1, m, &cBinop_Cl6eqrT4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_H1i6FBWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8AhZXRTB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8AhZXRTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExzK2ek1, HV_BINOP_MULTIPLY, 1, m, &cBinop_ExzK2ek1_sendMessage);
}

void Heavy_WSTD_3Q::cVar_3HJ5kP8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VHBjb1jP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_kcGPuV9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1z98ZNGy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_waQlQwxF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KBx6PJOl_sendMessage);
}

void Heavy_WSTD_3Q::cVar_K5PwU1DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xbwjmURA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KSO09gKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8uedErER_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2b620S50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NoPJ0DBy_sendMessage);
}

void Heavy_WSTD_3Q::cSend_8vTdyCDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ND4naeco_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_00j7h9p8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_94jPXDir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_W2E8crIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zd5tUabP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rvbn1CNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0jTZ6PQr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0jTZ6PQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zGzNEn6W, HV_BINOP_MULTIPLY, 1, m, &cBinop_zGzNEn6W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zGzNEn6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8oTOyeQu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8oTOyeQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W2E8crIE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_VHBjb1jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RDuytCyo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RDuytCyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_unX1HTM4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t1RHbxFu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V89rpWb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y3PBmuBj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yIj6C68J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7yUBnAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_m2Pzixct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6HtiuIQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Cl6eqrT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_brr7eJwQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ExzK2ek1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M936CRPZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_lXBkMMUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kcGPuV9D, 0, m, &cVar_kcGPuV9D_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZilR58xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K5PwU1DF, 1, m, &cVar_K5PwU1DF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1z98ZNGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K5PwU1DF, 0, m, &cVar_K5PwU1DF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KBx6PJOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3HJ5kP8w, 0, m, &cVar_3HJ5kP8w_sendMessage);
}

void Heavy_WSTD_3Q::cCast_unX1HTM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExzK2ek1, HV_BINOP_MULTIPLY, 0, m, &cBinop_ExzK2ek1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_t1RHbxFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cl6eqrT4, HV_BINOP_MULTIPLY, 0, m, &cBinop_Cl6eqrT4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_y3PBmuBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIj6C68J, HV_BINOP_MULTIPLY, 0, m, &cBinop_yIj6C68J_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V89rpWb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2Pzixct, HV_BINOP_MULTIPLY, 0, m, &cBinop_m2Pzixct_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_e7qYSrbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ph5wz5wv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_92kT11Kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wekJjeWu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_G6xV0h1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rE1aCwPP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MZBic8FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oOZq4vOK, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OgQKp9cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DFGY3RVD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kCWmTIwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7RneCbWk_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_7RneCbWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1K9icLL2, HV_BINOP_DIVIDE, 1, m, &cBinop_1K9icLL2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LrwDy1Vq_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Sb8kWwks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_b3DPmFZJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DfPu5u1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Sb8kWwks_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b3DPmFZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1K9icLL2, HV_BINOP_DIVIDE, 0, m, &cBinop_1K9icLL2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LrwDy1Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DfPu5u1D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1K9icLL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnbMs8yr, HV_BINOP_MULTIPLY, 1, m, &cBinop_mnbMs8yr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mnbMs8yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bYaLYfgX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b1k6PHwH_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_VN8z1NAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FypXKrdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_5OqTgBPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bbjVSl94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_20sEGvi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qZjyutEu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qZjyutEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnbMs8yr, HV_BINOP_MULTIPLY, 0, m, &cBinop_mnbMs8yr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c0X3JU83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gfkQWoDw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gfkQWoDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ur3wpaMI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PaBtKyQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4YpgaIH, HV_BINOP_MULTIPLY, 1, m, &cBinop_g4YpgaIH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pNnco1X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Z5nnGnWY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z5nnGnWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PaBtKyQD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YXsR1GdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OSz7X4sZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OSz7X4sZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U2hgCqtd, HV_BINOP_MULTIPLY, 1, m, &cBinop_U2hgCqtd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k4vpay0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LoNEV675, HV_BINOP_MULTIPLY, 1, m, &cBinop_LoNEV675_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kvRTuGWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7VOO5def_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7VOO5def_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k4vpay0t_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3wbEOvKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CTBr7ygQ, 1, m, &cVar_CTBr7ygQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dkzEWcHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfjfzTGD, HV_BINOP_MULTIPLY, 1, m, &cBinop_DfjfzTGD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8zgCB3wC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_a5FCRwF4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a5FCRwF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkjEK34V, HV_BINOP_MULTIPLY, 1, m, &cBinop_MkjEK34V_sendMessage);
}

void Heavy_WSTD_3Q::cVar_CTBr7ygQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rLtJowY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_zlbcSfxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J0FA6pmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_20sEGvi7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rdLdqnRx_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vkabla4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_c0X3JU83_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bYaLYfgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VN8z1NAm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_b1k6PHwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5OqTgBPo_sendMessage);
}

void Heavy_WSTD_3Q::cSend_FypXKrdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ugLO0mks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_bbjVSl94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CCLh7yUt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iBcrUfhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dbe6OoTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Ur3wpaMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pN5VE2Uc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pN5VE2Uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KZDehmxK, HV_BINOP_MULTIPLY, 1, m, &cBinop_KZDehmxK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KZDehmxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9BDfzcS6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9BDfzcS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iBcrUfhU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rLtJowY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5j3lMXQy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5j3lMXQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kd5KDUuy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9MqmtuQ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5M9D25D8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yhGPKUfo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q843MS6v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5JVf2oYc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g4YpgaIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e7qYSrbl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_U2hgCqtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92kT11Kj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LoNEV675_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G6xV0h1Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DfjfzTGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZBic8FK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MkjEK34V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OgQKp9cH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_LNeBWfIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vkabla4X, 1, m, &cVar_vkabla4X_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TMjZXxLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zlbcSfxx, 0, m, &cVar_zlbcSfxx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5M9D25D8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfjfzTGD, HV_BINOP_MULTIPLY, 0, m, &cBinop_DfjfzTGD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5JVf2oYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4YpgaIH, HV_BINOP_MULTIPLY, 0, m, &cBinop_g4YpgaIH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Q843MS6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U2hgCqtd, HV_BINOP_MULTIPLY, 0, m, &cBinop_U2hgCqtd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9MqmtuQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkjEK34V, HV_BINOP_MULTIPLY, 0, m, &cBinop_MkjEK34V_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Kd5KDUuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_yhGPKUfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LoNEV675, HV_BINOP_MULTIPLY, 0, m, &cBinop_LoNEV675_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rdLdqnRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CTBr7ygQ, 0, m, &cVar_CTBr7ygQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_J0FA6pmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vkabla4X, 0, m, &cVar_vkabla4X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ylRHr95a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lpJ6Vb9D, 1, m, &cIf_lpJ6Vb9D_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GijI2T6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4hr1OybL, m);
}

void Heavy_WSTD_3Q::cBinop_ut9PcNCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GijI2T6p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_uccj9LXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lpJ6Vb9D, 0, m, &cIf_lpJ6Vb9D_sendMessage);
}

void Heavy_WSTD_3Q::cVar_2LCh0U3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_77BDfbso, HV_BINOP_DIVIDE, 0, m, &cBinop_77BDfbso_sendMessage);
}

void Heavy_WSTD_3Q::cVar_0qD5yVgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1aVOd1PC, HV_BINOP_DIVIDE, 1, m, &cBinop_1aVOd1PC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_77BDfbso, HV_BINOP_DIVIDE, 1, m, &cBinop_77BDfbso_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MhhaPAlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WJDehcUc, HV_BINOP_DIVIDE, 0, m, &cBinop_WJDehcUc_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_7EYcwG0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WJDehcUc, HV_BINOP_DIVIDE, 1, m, &cBinop_WJDehcUc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ySe6m5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2LCh0U3M, 0, m, &cVar_2LCh0U3M_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aNZSQp4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1aVOd1PC, HV_BINOP_DIVIDE, 0, m, &cBinop_1aVOd1PC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kITzeKzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0qD5yVgc, 0, m, &cVar_0qD5yVgc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1aVOd1PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_MhhaPAlf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_77BDfbso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_7EYcwG0K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WJDehcUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_10y5soes_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_EBgPRp3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_SHjYHh7s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9XPXS61J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_0XFxbWId_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_10y5soes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9XPXS61J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0XFxbWId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_EBgPRp3D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SHjYHh7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_03QwaDXx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_w84TYIsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_W61BDa1L_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OdqdytnH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KJQvPHLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_W61BDa1L_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OdqdytnH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_rGVI0L3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_W61BDa1L_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OdqdytnH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QDENlJVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_W61BDa1L_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OdqdytnH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_03QwaDXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_W61BDa1L_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OdqdytnH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jl8MVL6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zd2aB6k7, 0, m, &cVar_zd2aB6k7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fU2uxrWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_nBIGzMcK, 0, m, &cVar_nBIGzMcK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jIeXkevX, 0, m, &cVar_jIeXkevX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6AaoZo3A, 0, m, &cVar_6AaoZo3A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RxtAxjEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nBIGzMcK, 0, m, &cVar_nBIGzMcK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cdU2sp5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jIeXkevX, 0, m, &cVar_jIeXkevX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_loG2AA6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6AaoZo3A, 0, m, &cVar_6AaoZo3A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_FXgKrW2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jJPI72L2, 0, m, &cVar_jJPI72L2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_BMEtN8kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aPJKHxDo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YWKGLpIb_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_qrDkEgow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkWKiObo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5JG4Eaoz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oXORB5PU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZAOTSyX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZONJghd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GjvXKp7G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OSisgjqz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_poA8csgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3ITPq11s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vcEtxGqi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7xBL0oiy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zmBa1npv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E6nuorEg_sendMessage(_c, 0, m);
  cMsg_wQP59lUF_sendMessage(_c, 0, m);
  cMsg_g314zROa_sendMessage(_c, 0, m);
  cMsg_itNxQVcU_sendMessage(_c, 0, m);
  cMsg_xTW90t21_sendMessage(_c, 0, m);
  cMsg_kCWmTIwk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fYQgc4Fp, 0, m, &cVar_fYQgc4Fp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jJPI72L2, 0, m, &cVar_jJPI72L2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WTJ8asky, 0, m, &cVar_WTJ8asky_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hFU0TU6g, 0, m, &cVar_hFU0TU6g_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kcGPuV9D, 0, m, &cVar_kcGPuV9D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zlbcSfxx, 0, m, &cVar_zlbcSfxx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jXKnrMvd, 0, m, &cVar_jXKnrMvd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oUOcS75y, 0, m, &cVar_oUOcS75y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KMNrn3Uk, 0, m, &cVar_KMNrn3Uk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zhQEathA, 0, m, &cVar_zhQEathA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_u4OXlDc6, 0, m, &cVar_u4OXlDc6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0hDZSxUS, 0, m, &cVar_0hDZSxUS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v5xcYwuJ, 0, m, &cVar_v5xcYwuJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3dbqqcIP, 0, m, &cVar_3dbqqcIP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O3MfrEIQ, 0, m, &cVar_O3MfrEIQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TsxJcyEA, 0, m, &cVar_TsxJcyEA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_14piqSnu, 0, m, &cVar_14piqSnu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TkTC5wzf, 0, m, &cVar_TkTC5wzf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1htbHs2G, 0, m, &cVar_1htbHs2G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IEjF5kcn, 0, m, &cVar_IEjF5kcn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qVa5CoQT, 0, m, &cVar_qVa5CoQT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KmICst43, 0, m, &cVar_KmICst43_sendMessage);
  cMsg_fU2uxrWX_sendMessage(_c, 0, m);
  cMsg_jl8MVL6t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_QI9rTeql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zC3HCOMj, HV_BINOP_MULTIPLY, 0, m, &cBinop_zC3HCOMj_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jiUip2dO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_l1y8xJsX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MrVrOBde_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ks8w4kQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_jqSxoDSb_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kX19EfPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KndyxLDc_sendMessage);
  cMsg_DZsDZZDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_HPkYTAuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fxreq2Wk, HV_BINOP_MULTIPLY, 0, m, &cBinop_fxreq2Wk_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TuBkdKGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5svgrW9R_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_c7LT8YBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfznwq6N, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qfznwq6N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5JtTDLU3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dzY58SSc_sendMessage);
  cMsg_nimFLDXI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_y2elEdvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOWdgAv9, HV_BINOP_MULTIPLY, 0, m, &cBinop_WOWdgAv9_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_E87M2CQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GGE1rYHl_sendMessage(_c, 0, m);
  cMsg_Aq97YVZq_sendMessage(_c, 0, m);
  cMsg_obPOaaS5_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iNvzc6ng_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_QSB3E3FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C5JtRR4M_sendMessage);
  cMsg_NYNS9cHT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_CK9HB9nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kcGPuV9D, 0, m, &cVar_kcGPuV9D_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_wFw3T7ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZilR58xo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lXBkMMUM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_yNfehG6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HsMiGMKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7KAxHl4g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qxj44S9y_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lItdxfh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_so3UiyI4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UNpqgrMC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4edaiK1H_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kipCmF50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AHSSpYjz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3LSoWQNt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4lnwT8d4_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bNQ8BcJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GmIiixRk, HV_BINOP_MULTIPLY, 0, m, &cBinop_GmIiixRk_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1EKXvoDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yMECjTXz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jHNUhx5l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_F4RxmQmm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WFrUNmGN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_57Lmdx8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EprHQPPO_sendMessage);
  cMsg_YTC278iu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_ND4naeco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zGzNEn6W, HV_BINOP_MULTIPLY, 0, m, &cBinop_zGzNEn6W_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_94jPXDir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9BuLklvu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zd5tUabP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIj6C68J, HV_BINOP_MULTIPLY, 1, m, &cBinop_yIj6C68J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8S1godJ6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wvtLlJ8U_sendMessage);
  cMsg_H1i6FBWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_ugLO0mks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KZDehmxK, HV_BINOP_MULTIPLY, 0, m, &cBinop_KZDehmxK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CCLh7yUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pNnco1X9_sendMessage(_c, 0, m);
  cMsg_YXsR1GdR_sendMessage(_c, 0, m);
  cMsg_kvRTuGWe_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dkzEWcHV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dbe6OoTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3wbEOvKO_sendMessage);
  cMsg_8zgCB3wC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_hsCASmsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zd2aB6k7, 0, m, &cVar_zd2aB6k7_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_aynAEb8C, VOf(Bf0));
    __hv_line_f(&sLine_hlApwzOz, VOf(Bf1));
    __hv_line_f(&sLine_gIYaub3a, VOf(Bf2));
    __hv_line_f(&sLine_iYO4U9Np, VOf(Bf3));
    __hv_line_f(&sLine_PH8Hqmvh, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_PZaULxzs, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_CMCY7tRq, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_V3spw9cM, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_nLdyUjSb, VOf(Bf1));
    __hv_line_f(&sLine_KYvrgQlD, VOf(Bf0));
    __hv_line_f(&sLine_iAvWVcrz, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_a0XuTXEg, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_oA8nObyB, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_ijS71e7X, VOf(Bf5));
    __hv_line_f(&sLine_9d9rS7On, VOf(Bf1));
    __hv_line_f(&sLine_Wzb8va57, VOf(Bf2));
    __hv_line_f(&sLine_Mc8UP7ku, VOf(Bf4));
    __hv_line_f(&sLine_nFvjXvJu, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_JBQrd8RY, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_hDI3n8ti, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_88m0XVni, VOf(Bf6));
    __hv_line_f(&sLine_jqLi9QM8, VOf(Bf2));
    __hv_line_f(&sLine_LUcGbCh0, VOf(Bf1));
    __hv_line_f(&sLine_49yy14gq, VOf(Bf5));
    __hv_line_f(&sLine_nlkCGVGD, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_lB3PrM5d, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_unnWmTAL, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_cs164SZm, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_DmvR6kcV, VOf(Bf2));
    __hv_line_f(&sLine_Ckfg0tEU, VOf(Bf6));
    __hv_line_f(&sLine_zkE7rwvY, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_cOxCk2SY, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4hr1OybL, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Ph5wz5wv, VOf(Bf8));
    __hv_line_f(&sLine_wekJjeWu, VOf(Bf2));
    __hv_line_f(&sLine_rE1aCwPP, VOf(Bf1));
    __hv_line_f(&sLine_oOZq4vOK, VOf(Bf7));
    __hv_line_f(&sLine_DFGY3RVD, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_xGodU9nS, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_I5XPkGFU, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
